@@ -14,7 +14,7 @@ inputfile=$3
 
 env -i bin/gt sequniq -rev $inputfile > tmp.fas
 sfxopt="-pl 2 -dna -lcp -suf -tis -ssp -db tmp.fas"
-if test ${mirrored} == "m"
+if test ${mirrored} = "m"
 then
   idx="sfx-m"
 else
