@@ -31,7 +31,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include "core/error.h"
+#include "core/error_api.h"
 #include "core/types_api.h"
 
 /** basic unit of addressing BitStrings */
