@@ -21,7 +21,7 @@
 #define ENCSEQ_H
 
 #include "core/alphabet.h"
-#include "core/chardef.h"
+#include "core/chardef_api.h"
 #include "core/codetype.h"
 #include "core/disc_distri_api.h"
 #include "core/encseq_api.h"
@@ -29,13 +29,13 @@
 #include "core/encseq_options.h"
 #include "core/filelengthvalues.h"
 #include "core/intbits.h"
-#include "core/md5_tab.h"
-#include "core/range.h"
+#include "core/md5_tab_api.h"
+#include "core/range_api.h"
 #include "core/readmode.h"
-#include "core/str.h"
+#include "core/str_api.h"
 #include "core/str_array.h"
 #include "core/types_api.h"
-#include "core/arraydef.h"
+#include "core/arraydef_api.h"
 
 #define GT_ENCSEQ_VERSION  3
 
@@ -75,7 +75,7 @@ typedef struct
 
 /* Stores the decoded version of the substring from 0-based position <frompos>
    to position <topos> of <encseq>. If the extracted region contains a separator
-   character, it will be represented by non-printable SEPARATOR constant.
+   character, it will be represented by non-printable GT_SEPARATOR constant.
    The caller is responsible to handle this case. The result of the extraction
    is written to the location pointed to by <buffer>, which must be sufficiently
    large to hold the result. The function is identical to
@@ -373,7 +373,7 @@ bool gt_encseq_contains_special(const GtEncseq *encseq,
                                 GtUword len);
 
 /* Returns the sequence number from the given <position> for an array of
-  SEPARATOR positions <recordseps>.  */
+  GT_SEPARATOR positions <recordseps>.  */
 GtUword gt_encseq_sep2seqnum(const GtUword *recordseps,
                                    GtUword numofrecords,
                                    GtUword totalwidth,
