@@ -21,12 +21,12 @@
 #include <string.h>
 #include "gt_config.h"
 #include "core/cstr_api.h"
-#include "core/error.h"
-#include "core/fa.h"
+#include "core/error_api.h"
+#include "core/fa_api.h"
 #include "core/fileutils_api.h"
 #include "core/hashmap_api.h"
 #include "core/grep_api.h"
-#include "core/ma.h"
+#include "core/ma_api.h"
 #include "core/mail_address.h"
 #include "core/option.h"
 #include "core/parseutils.h"
@@ -34,7 +34,7 @@
 #include "core/unused_api.h"
 #include "core/warning_api.h"
 #include "core/xansi_api.h"
-#include "core/xposix.h"
+#include "core/xposix_api.h"
 
 typedef enum {
   OPTION_BOOL,
