@@ -23,25 +23,10 @@
 int gt_tooldriver(GtToolFunc tool, int argc, char *argv[])
 {
   gt_assert(tool && argv);
-  return gt_tooldriver_with_license(tool, argc, argv, NULL, NULL, NULL);
-}
-
-int gt_tooldriver_with_license(GtToolFunc tool, int argc, char *argv[],
-                               GtLicense **license_out,
-                               GtLicenseConstructor license_constructor,
-                               GtLicenseDestructor license_destructor)
-{
-  GtLicense *license = NULL;
   GtError *err;
   int had_err;
   gt_lib_init();
   gt_assert(tool && argv);
-  if (license_constructor) {
-    if (!(license = license_constructor(argv[0])))
-      return EXIT_FAILURE;
-    if (license_out)
-      *license_out = license;
-  }
   err = gt_error_new();
   gt_error_set_progname(err, argv[0]);
   had_err = tool(argc, (const char**) argv, err);
@@ -51,8 +36,6 @@ int gt_tooldriver_with_license(GtToolFunc tool, int argc, char *argv[],
     gt_assert(had_err);
   }
   gt_error_delete(err);
-  if (license_destructor)
-    license_destructor(license);
   if (gt_lib_clean())
     return GT_EXIT_PROGRAMMING_ERROR; /* programmer error */
   if (had_err)
@@ -64,28 +47,11 @@ int gt_toolobjdriver(GtToolConstructor tool_constructor,
                      GtShowVersionFunc version_func, int argc, char *argv[])
 {
   gt_assert(tool_constructor && argv);
-  return gt_toolobjdriver_with_license(tool_constructor, version_func, argc,
-                                       argv, NULL, NULL, NULL);
-}
-
-int gt_toolobjdriver_with_license(GtToolConstructor tool_constructor,
-                                  GtShowVersionFunc version_func, int argc,
-                                  char *argv[], GtLicense **license_out,
-                                  GtLicenseConstructor license_constructor,
-                                  GtLicenseDestructor license_destructor)
-{
-  GtLicense *license = NULL;
   GtTool *tool;
   GtError *err;
   int had_err;
   gt_lib_init();
   gt_assert(tool_constructor && argv);
-  if (license_constructor) {
-    if (!(license = license_constructor(argv[0])))
-      return EXIT_FAILURE;
-    if (license_out)
-      *license_out = license;
-  }
   err = gt_error_new();
   gt_error_set_progname(err, argv[0]);
   tool = tool_constructor();
@@ -101,8 +67,6 @@ int gt_toolobjdriver_with_license(GtToolConstructor tool_constructor,
     gt_assert(had_err);
   }
   gt_error_delete(err);
-  if (license_destructor)
-    license_destructor(license);
   if (gt_lib_clean())
     return GT_EXIT_PROGRAMMING_ERROR; /* programmer error */
   if (had_err)
