@@ -18,21 +18,21 @@
 #include <string.h>
 #include <stddef.h>
 
-#include "core/arraydef.h"
+#include "core/arraydef_api.h"
 #include "core/disc_distri_api.h"
-#include "core/divmodmul.h"
-#include "core/fa.h"
+#include "core/divmodmul_api.h"
+#include "core/fa_api.h"
 #include "core/log_api.h"
 #include "core/logger.h"
-#include "core/ma.h"
+#include "core/ma_api.h"
 #include "core/range_api.h"
-#include "core/safearith.h"
+#include "core/safearith_api.h"
 #include "core/showtime.h"
 #include "core/str_array.h"
 #include "core/undef_api.h"
 #include "core/unused_api.h"
 #include "extended/kmer_database.h"
-#include "extended/rbtree.h"
+#include "extended/rbtree_api.h"
 #include "match/sfx-mappedstr.h"
 #include "match/xdrop.h"
 
