@@ -563,6 +563,7 @@ static int process_id_attr(const char *id, GtFeatureNode *feature_node,
                                                 parser->feature_info);
             replace_node(fn, pseudo_node, genome_nodes);
             gt_feature_node_add_child(pseudo_node, feature_node);
+            update_pseudo_node_range(pseudo_node, feature_node);
             *is_child = true;
           }
         }
@@ -718,6 +719,22 @@ static void join_roots(GtArray *roots, GtFeatureInfo *feature_info,
   }
 }
 
+static void dedup_roots(GtArray *roots)
+{
+  GtUword i = 0,
+          j = 0;
+  gt_assert(roots);
+  for (i = 0; i < gt_array_size(roots); i++) {
+    for (j = i+1; j < gt_array_size(roots); j++) {
+      if (*(GtGenomeNode**) gt_array_get(roots, i)
+            == *(GtGenomeNode**) gt_array_get(roots, j)) {
+        gt_array_rem(roots, j);
+        j--;
+      }
+    }
+  }
+}
+
 static int process_child(GtGenomeNode *child, GtSplitter *parent_splitter,
                          GtFeatureInfo *feature_info, bool strict,
                          unsigned int last_terminator,
@@ -736,7 +753,28 @@ static int process_child(GtGenomeNode *child, GtSplitter *parent_splitter,
     parent_gf = (GtGenomeNode*) gt_feature_info_get(feature_info,
                                                     parent);
     gt_assert(parent_gf);
-    if (gt_genome_node_get_line_number(parent_gf) < last_terminator) {
+    if (gt_str_cmp(gt_genome_node_get_seqid(parent_gf),
+                        gt_genome_node_get_seqid(child))) {
+      gt_error_set(err, "child on line %u in file \"%s\" has different "
+                   "sequence id than its parent on line %u ('%s' vs. '%s')",
+                   gt_genome_node_get_line_number(child),
+                   gt_genome_node_get_filename(child),
+                   gt_genome_node_get_line_number(parent_gf),
+                   gt_str_get(gt_genome_node_get_seqid(child)),
+                   gt_str_get(gt_genome_node_get_seqid(parent_gf)));
+      gt_genome_node_delete(child);
+      had_err = -1;
+    }
+    if (!had_err && parent_gf == child) {
+      gt_error_set(err, "feature on line %u in file \"%s\" is "
+                   "self-referential (%s and %s are the same)",
+                   gt_genome_node_get_line_number(child),
+                   gt_genome_node_get_filename(child),
+                   GT_GFF_PARENT, GT_GFF_ID);
+      gt_genome_node_delete(child);
+      had_err = -1;
+    }
+    if (!had_err && gt_genome_node_get_line_number(parent_gf) < last_terminator) {
       gt_error_set(err, "the child with %s \"%s\" on line %u in file "
                    "\"%s\" is separated from its corresponding %s on line %u "
                    "by terminator %s on line %u", GT_GFF_PARENT, parent,
@@ -798,6 +836,7 @@ static int process_child(GtGenomeNode *child, GtSplitter *parent_splitter,
     /* make sure all (valid) parents have the same (pseudo-)root */
     if (gt_str_array_size(valid_parents) >= 2) {
       GtArray *roots = find_roots(valid_parents, feature_info);
+      dedup_roots(roots);
       if (roots_differ(roots))
         join_roots(roots, feature_info, genome_nodes);
       gt_array_delete(roots);
@@ -850,23 +889,6 @@ static int process_parent_attr(char *parent_attr, GtGenomeNode *feature_node,
       /* children of orphaned parents are orphans themselves */
       orphaned_parent = true;
     }
-    else if (gt_str_cmp(gt_genome_node_get_seqid(parent_gf),
-                        gt_genome_node_get_seqid(feature_node))) {
-      gt_error_set(err, "child on line %u in file \"%s\" has different "
-                   "sequence id than its parent on line %u ('%s' vs. '%s')",
-                   gt_genome_node_get_line_number(feature_node), filename,
-                   gt_genome_node_get_line_number(parent_gf),
-                   gt_str_get(gt_genome_node_get_seqid(feature_node)),
-                   gt_str_get(gt_genome_node_get_seqid(parent_gf)));
-      had_err = -1;
-    }
-    else if (parent_gf == feature_node) {
-      gt_error_set(err, "feature on line %u in file \"%s\" is "
-                   "self-referential (%s and %s are the same)",
-                   gt_genome_node_get_line_number(feature_node), filename,
-                   GT_GFF_PARENT, GT_GFF_ID);
-      had_err = -1;
-    }
   }
 
   if (!had_err) {
