@@ -20,9 +20,9 @@
 #include "core/class_alloc_lock.h"
 #include "core/cstr_api.h"
 #include "core/encseq.h"
-#include "core/hashmap.h"
+#include "core/hashmap_api.h"
 #include "core/log.h"
-#include "core/ma.h"
+#include "core/ma_api.h"
 #include "core/str_array.h"
 #include "core/undef_api.h"
 #include "core/unused_api.h"
@@ -30,7 +30,7 @@
 #include "extended/clustered_set_uf.h"
 #include "extended/feature_node.h"
 #include "extended/feature_node_iterator_api.h"
-#include "extended/feature_type.h"
+#include "extended/feature_type_api.h"
 #include "extended/node_stream_api.h"
 #include "extended/match.h"
 #include "extended/match_iterator_api.h"
@@ -321,7 +321,7 @@ static int cluster_annotate_nodes(GtClusteredSet *cs, GtEncseq *encseq,
       continue;
     fni = gt_feature_node_iterator_new((GtFeatureNode*) gn);
     while ((curnode = gt_feature_node_iterator_next(fni)) != NULL) {
-      char header[BUFSIZ];
+      char header[2*BUFSIZ];
       fnt = gt_feature_node_get_type(curnode);
       if (strcmp(fnt, gt_ft_repeat_region) == 0) {
         const char *rid;
@@ -341,7 +341,7 @@ static int cluster_annotate_nodes(GtClusteredSet *cs, GtEncseq *encseq,
         range = gt_genome_node_get_range((GtGenomeNode*) curnode);
         if ((range.end - range.start + 1) < 10UL)
           continue;
-        (void) snprintf(header, BUFSIZ, "%s_"GT_WU"_"GT_WU"", buffer,
+        (void) snprintf(header, 2*BUFSIZ, "%s_"GT_WU"_"GT_WU"", buffer,
                         range.start, range.end);
         gt_hashmap_add(desc2node, (void*) gt_cstr_dup(header), (void*) curnode);
       } else if (strcmp(fnt, real_feature) == 0) {
@@ -349,7 +349,7 @@ static int cluster_annotate_nodes(GtClusteredSet *cs, GtEncseq *encseq,
         range = gt_genome_node_get_range((GtGenomeNode*) curnode);
         if ((range.end - range.start + 1) < 10UL)
           continue;
-        (void) snprintf(header, BUFSIZ, "%s_"GT_WU"_"GT_WU"", buffer,
+        (void) snprintf(header, 2*BUFSIZ, "%s_"GT_WU"_"GT_WU"", buffer,
                         range.start, range.end);
         gt_hashmap_add(desc2node, (void*) gt_cstr_dup(header), (void*) curnode);
       }
@@ -497,7 +497,7 @@ static int gt_ltr_cluster_stream_next(GtNodeStream *ns,
       if (had_err) {
         gt_genome_node_delete(*gn);
         *gn = NULL;
-        break;
+        return had_err;
       }
     }
     lcs->feat_to_encseq =
