@@ -479,8 +479,9 @@ static void ppt_attach_results_to_gff3(GtLTRdigestPPTVisitor *lv,
     /* find best-scoring PPT on the given canonical strand */
     while (hit->strand != *canonical_strand
              && i < gt_ppt_results_get_number_of_hits(results)) {
+      const char *msg = gt_feature_node_get_attribute(mainnode, "ID");
       gt_log_log("dropping PPT because of nonconsistent strand: %s\n",
-                 gt_feature_node_get_attribute(mainnode, "ID"));
+                 msg == NULL ? "undefined" : msg);
       hit = gt_ppt_results_get_ranked_hit(results, i++);
     }
     /* if there is none, do not report a PPT */
