@@ -22,8 +22,8 @@
 
 #include "core/bitpackstring.h"
 #include "match/dataalign.h"
-#include "core/fa.h"
-#include "core/str.h"
+#include "core/fa_api.h"
+#include "core/str_api.h"
 #include "core/xansi_api.h"
 
 #include "match/eis-bitpackseqpos.h"
@@ -75,7 +75,7 @@ initBWTSeqContextRetrieverFactory(BWTSeqContextRetrieverFactory *newFactory,
   newFactory->mapTableDBSPath = gt_str_new();
   fp = newFactory->mapTableDiskBackingStore
     = gt_xtmpfp_generic(newFactory->mapTableDBSPath,
-                        TMPFP_AUTOREMOVE | TMPFP_OPENBINARY);
+                        GT_TMPFP_AUTOREMOVE | GT_TMPFP_OPENBINARY);
   {
     off_t backingStoreSize = numMapEntries(seqLen, mapIntervalLog2), i;
     GtUword buf[BLOCK_IO_SIZE];
@@ -141,7 +141,7 @@ gt_BWTSCRFReadAdvance(BWTSeqContextRetrieverFactory *factory,
   gt_assert(factory);
   while (sfxIdxLeft)
   {
-    GtUword len = MIN(BLOCK_IO_SIZE, sfxIdxLeft);
+    GtUword len = GT_MIN(BLOCK_IO_SIZE, sfxIdxLeft);
     if (SDRRead(readSfxIdx, buf, len)
         != len)
     {
@@ -287,7 +287,7 @@ BWTSeqCRMapOpen(unsigned short mapIntervalLog2,
                             seqLen, mapIntervalLog2));
     mapName = gt_str_new_cstr(projectName);
     {
-      char buf[1 + 4 + 3 + 2];
+      char buf[1 + 4 + 3 + 3];
       snprintf(buf, sizeof (buf), ".%ucxm", (unsigned)mapIntervalLog2);
       gt_str_append_cstr(mapName, buf);
       if (createMapFile)
