@@ -274,7 +274,7 @@ static void front_trace2eoplist_directed(GtEoplist *eoplist,
                                          const GtFtPolished_point *pp)
 {
   GtUword distance, localoffset, globaloffset, remainingvalidfronts,
-          totalrunlength = 0, trimleft;
+          trimleft;
   GtWord diagonal;
   unsigned int row, lcs;
   uint8_t trace, preferred_eop = FT_EOP_MISMATCH;
@@ -310,7 +310,6 @@ static void front_trace2eoplist_directed(GtEoplist *eoplist,
     }
     if (trace & preferred_eop)
     {
-      totalrunlength++;
       if (preferred_eop == FT_EOP_MISMATCH)
       {
         nextrowadd = 1;
@@ -540,7 +539,8 @@ static void gt_front_trace_backtracepath2eoplist(GtEoplist *eoplist,
                                                 GT_UNUSED GtUword ulen,
                                                 GT_UNUSED GtUword vlen)
 {
-  GtUword idx, deletions = 0, insertions = 0, mismatches = 0, matches = 0;
+  GtUword idx, GT_UNUSED deletions = 0, GT_UNUSED insertions = 0, 
+          GT_UNUSED mismatches = 0, GT_UNUSED matches = 0;
 
   if (lastlcs > 0)
   {
