@@ -24,23 +24,23 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #endif
-#include "core/arraydef.h"
+#include "core/arraydef_api.h"
 #include "core/assert_api.h"
-#include "core/chardef.h"
+#include "core/chardef_api.h"
 #include "core/error_api.h"
 #include "core/unused_api.h"
 #include "core/progressbar.h"
-#include "core/minmax.h"
-#include "core/fa.h"
+#include "core/minmax_api.h"
+#include "core/fa_api.h"
 #include "core/timer_api.h"
 #include "core/encseq.h"
 #include "core/safecast-gen.h"
 #include "core/log_api.h"
-#include "core/mathsupport.h"
+#include "core/mathsupport_api.h"
 #include "core/spacecalc.h"
-#include "core/divmodmul.h"
+#include "core/divmodmul_api.h"
 #include "core/format64.h"
-#include "core/fileutils.h"
+#include "core/fileutils_api.h"
 #ifdef GT_THREADS_ENABLED
 #include "core/thread_api.h"
 #endif
@@ -243,7 +243,7 @@ static GtCodetype getencseqcode(const GtEncseq *encseq,
   {
     gt_assert((GtUword) (pos + idx) < totallength);
     cc = gt_encseq_get_encoded_char_nospecial(encseq,pos + idx,readmode);
-    gt_assert(ISNOTSPECIAL(cc));
+    gt_assert(GT_ISNOTSPECIAL(cc));
     code += multimappower[idx][cc];
   }
   return code;
@@ -942,7 +942,7 @@ void getencseqkmers_rangetwobitencoding(const GtEncseq *encseq,
   }
 }
 
-void getencseqkmers_twobitencoding_slice(const GtEncseq *encseq,
+void gt_getencseqkmers_twobitencoding_slice(const GtEncseq *encseq,
                                          GtReadmode readmode,
                                          unsigned int kmersize,
                                          unsigned int upperkmersize,
@@ -1054,17 +1054,17 @@ void getencseqkmers_twobitencoding(const GtEncseq *encseq,
                                                              GtUword),
                                    void *processkmerspecialinfo)
 {
-  getencseqkmers_twobitencoding_slice(encseq,
-                                      readmode,
-                                      kmersize,
-                                      upperkmersize,
-                                      onlyfirst,
-                                      processkmercode,
-                                      processkmercodeinfo,
-                                      processkmerspecial,
-                                      processkmerspecialinfo,
-                                      0,
-                                      gt_encseq_total_length(encseq));
+  gt_getencseqkmers_twobitencoding_slice(encseq,
+                                         readmode,
+                                         kmersize,
+                                         upperkmersize,
+                                         onlyfirst,
+                                         processkmercode,
+                                         processkmercodeinfo,
+                                         processkmerspecial,
+                                         processkmerspecialinfo,
+                                         0,
+                                         gt_encseq_total_length(encseq));
 }
 
 static void gt_updateleftborderforkmer(Sfxiterator *sfi,
