@@ -16,11 +16,11 @@
 */
 
 #include "core/basename_api.h"
-#include "core/ma.h"
+#include "core/ma_api.h"
 #include "core/undef_api.h"
 #include "core/seq_iterator_fastq_api.h"
 #include "core/unused_api.h"
-#include "extended/feature_type.h"
+#include "extended/feature_type_api.h"
 #include "extended/gtdatahelp.h"
 #include "extended/hpol_processor.h"
 #include "tools/gt_hop.h"
