@@ -25,8 +25,8 @@
 #include "core/str_api.h"
 #include "core/tool_api.h"
 #include "core/unused_api.h"
-#include "core/versionfunc.h"
-#include "core/minmax.h"
+#include "core/versionfunc_api.h"
+#include "core/minmax_api.h"
 #include "core/encseq.h"
 #include "core/showtime.h"
 #include "core/timer_api.h"
