@@ -1481,8 +1481,6 @@ Test do
   run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua 1", :retval => 1
   run_test "#{$bin}gt gff3 -sort -retainids -sortlines #{$testdata}gt_gff3_linesort.in.gff3 > 2"
   run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua 2"
-  run_test "#{$bin}gt gff3 -sort -retainids 2 > 3"
-  run "diff 1 3"
 end
 
 Name "gt gff3 -sortlines (multiple sequences)"
@@ -1511,8 +1509,6 @@ Test do
   run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua 1", :retval => 1
   run_test "#{$bin}gt gff3 -sort -retainids -sortlines #{$testdata}standard_fasta_example.gff3 > 2"
   run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua 2"
-  run_test "#{$bin}gt gff3 -sort -retainids 2 > 3"
-  run "diff 1 3"
 end
 
 Name "gt gff3 -sortlines (spaces)"
@@ -1560,6 +1556,13 @@ Test do
   run "#{$bin}gt gff3 #{$testdata}/double_free.gff3", :retval => 1
 end
 
+Name "gt gff3 orphan validity checks"
+Keywords "gt_gff3"
+Test do
+  run "#{$bin}gt gff3 #{$testdata}/forward_wrong_seqid.gff3", :retval => 1
+  grep last_stderr, "has different sequence id than its parent on line 14"
+end
+
 def large_gff3_test(name, file)
   Name "gt gff3 #{name}"
   Keywords "gt_gff3 large_gff3"
